Skip to contents

Fit kmax for one scenario row

Usage

fitKmaxScenario(row, draws, weights, Da)

Arguments

row

one-row data.table containing TR, IDg, and a finite, positive PGA_rock in g.

draws

data.table with TR, IDg, ky, s, Dn, and IDn. PGA.s, the sampled PGA in g, is required for exact recovery of a flat AM88 realization.

weights

named numeric vector of active Newmark model weights by IDn.

Da

numeric displacement targets in cm.

Value

data.table with Da, p, kmax, IDn, PGA, Kh, TR, and IDg. The standard p family is mean, 0.05, 0.10, 0.16, 0.50, 0.84, 0.90 and 0.95. kmax and PGA are in g; Kh is 100 * kmax / PGA.