Fit Newmark displacement for multiple scenario rows
fitDnScenarios.RdFit Newmark displacement for multiple scenario rows
Arguments
- records
data.tableof scenario rows. Each row has the contract required byfitDnScenario(); itsUHSlist column may mix quantile and analytic spectra across rows.- weights
named numeric vector of active Newmark model weights by
IDn.- useParallel
logical. Use fork parallelism when available.
- workers
integer worker count when
useParallel = TRUE.