Build paired embankment geometries
getGeometry.RdHeights, truncation ratios and slopes are paired element by element. The geometry and its rounding are fixed by the shear-property workflow.
Value
A data.table with IDg, b, bmax, s, Hs and beta, where b is the
berm width of the truncation ratio lo = b / (2 * Hs * s + b) of the
article https://averrik.github.io/newmark/articles/dynamic-site-response.html.
Widths and heights are rounded to
metres, slopes to two decimals; beta is in degrees.